define("epi-changeapproval/command/ManageExpiration", [
   "dojo",
   "dojo/_base/declare",
   "dojo/_base/lang",
   "dojo/when",

   "epi/shell/widget/dialog/Dialog",

   "epi-cms/contentediting/command/ManageExpiration",
   "epi-cms/contentediting/ContentActionSupport",

   "epi-changeapproval/widget/ExpirationDialog",
   "epi-changeapproval/viewmodel/ExpirationDialogViewModel",

   "epi/i18n!epi/cms/nls/episerver.cms.widget.expirationeditor",
   "epi/i18n!epi/nls/episerver.shared"

], function (
   dojo,
   declare,
   lang,
   when,

   Dialog,

   ManageExpiration,
   ContentActionSupport,

   ExpirationDialog,
   ExpirationDialogViewModel,

   resources,
   sharedResources
) {
    return declare([ManageExpiration], {
        // summary:
        //      Command to display expiration dialog
        //
        // tags:
        //      internal

        createDialog: function () {
            // summary:
            //    Override to use changeapproval's ExpirationDialog instance.
            //
            // tags:
            //    internal

            var dialogViewModel = this.get("viewModel");

            var content = new ExpirationDialog({ model: dialogViewModel });

            return new Dialog({
                defaultActionsVisible: false,
                confirmActionText: sharedResources.action.save,
                content: content,
                title: resources.dialogtitle
            });
        },

        _onModelChange: function () {
            // summary:
            //    Override to use changeapproval's ExpirationDialogViewModel
            // tags:
            //    protected

            var model = this.get("model");
            if (!model || !model.contentData) {
                this.set("canExecute", false);
                return;
            }

            var properties = model.contentData.properties,
                expireBlock = properties.iversionable_expire;

            var canExecute = model.canChangeContent() &&
                             ContentActionSupport.hasAccess(model.contentData.accessMask, ContentActionSupport.accessLevel.Publish); // Ensure the user has Publish access right

            // Command is not available until the metadata resolves
            this.set("canExecute", false);

            when(model.getPropertyMetaData("iversionable_expire"), lang.hitch(this, function (metadata) {
                this.set("viewModel", new ExpirationDialogViewModel({
                    metadata: metadata,
                    contentLink: model.contentLink,
                    contentName: model.contentData.name,
                    value: expireBlock,
                    minimumExpireDate: properties.iversionable_startpublish
                }));

                this.set("canExecute", canExecute);
            }));
        },

        _onExecute: function () {

        }
    });
});
